.. redirect-from:: /users/prev_whats_new/github_stats_3.4.2

.. _github-stats-3-4-2:

GitHub statistics for 3.4.2 (May 08, 2021)
==========================================

GitHub statistics for 2021/03/31 (tag: v3.4.1) - 2021/05/08

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 21 issues and merged 97 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/63?closed=1>`__

The following 13 authors contributed 138 commits.

* AkM-2018
* Antony Lee
* David Stansby
* Elliott Sales de Andrade
* hannah
* Ian Thomas
* Jann Paul Mattern
* Jody Klymak
* pwohlhart
* richardsheridan
* Thomas A Caswell
* Tim Hoffmann
* Xianxiang Li

GitHub issues and pull requests:

Pull Requests (97):

* :ghpull:`20184`: Backport PR #20147 on branch v3.4.x (DOC: add example of labelling axes)
* :ghpull:`20181`: Backport PR #20171 on branch v3.4.x (Remove unsupported arguments from tricontourf documentation)
* :ghpull:`20180`: Backport PR #19876 on branch v3.4.x (FIX: re-order unit conversion and mask array coercion)
* :ghpull:`20171`: Remove unsupported arguments from tricontourf documentation
* :ghpull:`19876`: FIX: re-order unit conversion and mask array coercion
* :ghpull:`20178`: Backport PR #20150 on branch v3.4.x
* :ghpull:`20172`: Backport PR #20161 on branch v3.4.x (Fix resetting grid visibility)
* :ghpull:`20161`: Fix resetting grid visibility
* :ghpull:`20167`: Backport PR #20146 on branch v3.4.x (Don't clip clip paths to Figure bbox.)
* :ghpull:`20166`: Backport PR #19978 on branch v3.4.x (fixed bug in CenteredNorm, issue #19972)
* :ghpull:`20146`: Don't clip clip paths to Figure bbox.
* :ghpull:`19978`: fixed bug in CenteredNorm, issue #19972
* :ghpull:`20160`: Backport PR #20148 on branch v3.4.x (FIX: MouseButton representation in boilerplate generated signatures)
* :ghpull:`20148`: FIX: MouseButton representation in boilerplate generated signatures
* :ghpull:`20152`: Backport PR #20145 on branch v3.4.x (Fix broken link to ggplot in docs)
* :ghpull:`20139`: Backport PR #20135 on branch v3.4.x (Add tricontour/tricontourf arguments(corner_mask, vmin vmax, antialiased, nchunk, hatches) documentation)
* :ghpull:`20135`: Add tricontour/tricontourf arguments(corner_mask, vmin vmax, antialiased, nchunk, hatches) documentation
* :ghpull:`20136`: Backport PR #19959 on branch v3.4.x (Bugfix Tk start_event_loop)
* :ghpull:`19959`: Bugfix Tk start_event_loop
* :ghpull:`20128`: Backport PR #20123 on branch v3.4.x (Ensure that Matplotlib is importable even if there's no HOME.)
* :ghpull:`20123`: Ensure that Matplotlib is importable even if there's no HOME.
* :ghpull:`20009`: Fix removal of shared polar axes.
* :ghpull:`20104`: Backport PR #19686 on branch v3.4.x (Declare sphinxext.redirect_from parallel_read_safe)
* :ghpull:`19686`: Declare sphinxext.redirect_from parallel_read_safe
* :ghpull:`20098`: Backport PR #20096 on branch v3.4.x (Ignore errors for sip with no setapi.)
* :ghpull:`20096`: Ignore errors for sip with no setapi.
* :ghpull:`20087`: Backport PR #20083 on branch v3.4.x (Revert "Temporarily switch intersphinx to latest pytest.")
* :ghpull:`20085`: Backport PR #20082 on branch v3.4.x (Fix bar_label for bars with nan values)
* :ghpull:`20082`: Fix bar_label for bars with nan values
* :ghpull:`20076`: Backport PR #20062 on branch v3.4.x ([DOC] Add top-level .. module:: definition for matplotlib)
* :ghpull:`20043`: Backport PR #20041 on branch v3.4.x (Clarify docs for stackplot.)
* :ghpull:`20041`: Clarify docs for stackplot.
* :ghpull:`20039`: Backport PR #20037 on branch v3.4.x (Don't generate wheels unusable on PyPy7.3.{0,1}.)
* :ghpull:`20037`: Don't generate wheels unusable on PyPy7.3.{0,1}.
* :ghpull:`20033`: Backport PR #20031 on branch v3.4.x (Cleanup widget examples)
* :ghpull:`20031`: Cleanup widget examples
* :ghpull:`20022`: Backport PR #19949 on branch v3.4.x (FIX: subfigure indexing error)
* :ghpull:`19949`: FIX: subfigure indexing error
* :ghpull:`20018`: Backport PR #20017 on branch v3.4.x (FIX typos in imshow_extent.py)
* :ghpull:`20017`: FIX typos in imshow_extent.py
* :ghpull:`20015`: Backport PR #19962 on branch v3.4.x (Dev install troubleshooting)
* :ghpull:`19962`: Dev install troubleshooting
* :ghpull:`20002`: Backport PR #19995 on branch v3.4.x (Fix valinit argument to RangeSlider)
* :ghpull:`20004`: Backport PR #19999 on branch v3.4.x (DOC: add note about axes order to docstring)
* :ghpull:`19998`: Backport PR #19964 on branch v3.4.x (FIX: add subplot_mosaic axes in the order the user gave them to us)
* :ghpull:`19999`: DOC: add note about axes order to docstring
* :ghpull:`19997`: Backport PR #19992 on branch v3.4.x (Minor fixes to polar locator docstrings.)
* :ghpull:`19995`: Fix valinit argument to RangeSlider
* :ghpull:`19964`: FIX: add subplot_mosaic axes in the order the user gave them to us
* :ghpull:`19993`: Backport PR #19983 on branch v3.4.x (Fix handling of "d" glyph in backend_ps.)
* :ghpull:`19992`: Minor fixes to polar locator docstrings.
* :ghpull:`19991`: Backport PR #19987 on branch v3.4.x (Fix set_thetalim((min, max)).)
* :ghpull:`19976`: Backport PR #19970 on branch v3.4.x (Initialize members of PathClipper and check for m_has_init)
* :ghpull:`19983`: Fix handling of "d" glyph in backend_ps.
* :ghpull:`19987`: Fix set_thetalim((min, max)).
* :ghpull:`19970`: Initialize members of PathClipper and check for m_has_init
* :ghpull:`19973`: Backport PR #19971 on branch v3.4.x (Fix missing closing bracket in docs)
* :ghpull:`19971`: Fix missing closing bracket in docs
* :ghpull:`19966`: Backport PR #19963 on branch v3.4.x (test_StrCategoryLocator using parameterized plotter)
* :ghpull:`19965`: Backport PR #19961 on branch v3.4.x (FIX: subfigure tightbbox)
* :ghpull:`19963`: test_StrCategoryLocator using parameterized plotter
* :ghpull:`19961`: FIX: subfigure tightbbox
* :ghpull:`19953`: Backport PR #19919 on branch v3.4.x (Copy errorbar style normalization to 3D)
* :ghpull:`19919`: Copy errorbar style normalization to 3D
* :ghpull:`19950`: Backport PR #19948 on branch v3.4.x (Allow numpy arrays to be used as elinewidth)
* :ghpull:`19948`: Allow numpy arrays to be used as elinewidth
* :ghpull:`19944`: Backport PR #19939 on branch v3.4.x (add highlight-text to the third party packages list)
* :ghpull:`19921`: Backport PR #19913 on branch v3.4.x (Minor docstring improvement for set_aspect())
* :ghpull:`19920`: Backport PR #19903 on branch v3.4.x (Fix textbox cursor color, set its linewidth.)
* :ghpull:`19913`: Minor docstring improvement for set_aspect()
* :ghpull:`19903`: Fix textbox cursor color, set its linewidth.
* :ghpull:`19917`: Backport PR #19911 on branch v3.4.x (Shorten "how-to draw order")
* :ghpull:`19916`: Backport PR #19888 on branch v3.4.x (Fix errorbar drawstyle)
* :ghpull:`19911`: Shorten "how-to draw order"
* :ghpull:`19888`: Fix errorbar drawstyle
* :ghpull:`19910`: Backport PR #19895 on branch v3.4.x (Added PyPI info to third party page)
* :ghpull:`19895`: Added PyPI info to third party page
* :ghpull:`19896`: Backport PR #19893 on branch v3.4.x (Remove Howto: Plot numpy.datetime64 values)
* :ghpull:`19893`: Remove Howto: Plot numpy.datetime64 values
* :ghpull:`19886`: Backport PR #19881 on branch v3.4.x (Remove two sections from Plotting FAQ)
* :ghpull:`19877`: Backport PR #19863 on branch v3.4.x (Cleanup docstrings related to interactive mode)
* :ghpull:`19881`: Remove two sections from Plotting FAQ
* :ghpull:`19885`: Backport PR #19883 on branch v3.4.x (Small cleanups to FAQ.)
* :ghpull:`19883`: Small cleanups to FAQ.
* :ghpull:`19878`: Backport PR #19867 on branch v3.4.x (Remove "Use show()" from how-to )
* :ghpull:`19875`: Backport PR #19868 on branch v3.4.x (Remove "Install from source" from Installing FAQ)
* :ghpull:`19867`: Remove "Use show()" from how-to
* :ghpull:`19863`: Cleanup docstrings related to interactive mode
* :ghpull:`19868`: Remove "Install from source" from Installing FAQ
* :ghpull:`19874`: Backport PR #19847 on branch v3.4.x (Reformat references (part 2))
* :ghpull:`19847`: Reformat references (part 2)
* :ghpull:`19865`: Backport PR #19860 on branch v3.4.x (Move "howto interpreting box plots" to boxplot docstring)
* :ghpull:`19860`: Move "howto interpreting box plots" to boxplot docstring
* :ghpull:`19862`: Backport PR #19861 on branch v3.4.x (Remove FAQ Installing - Linux notes)
* :ghpull:`19861`: Remove FAQ Installing - Linux notes
* :ghpull:`18060`: Correctly handle 'none' facecolors in do_3d_projection
* :ghpull:`19846`: Backport PR #19788 on branch v3.4.x (Reformat references)

Issues (21):

* :ghissue:`19871`: Matplotlib >= v3.3.3 breaks with pandas.plotting.register_matplotlib_converters(), ax.pcolormesh(), and datetime objects
* :ghissue:`20149`: KeyError: 'gridOn' in axis.py when axis.tick_params() is used with reset = True
* :ghissue:`20127`: Zooming on a contour plot with clipping results in bad clipping
* :ghissue:`19972`: CenteredNorm with halfrange raises exception when passed to imshow
* :ghissue:`19940`: Tkagg event loop throws error on window close
* :ghissue:`20122`: Run in a system service / without configuration
* :ghissue:`19989`: Removal of y-shared polar axes causes crash at draw time
* :ghissue:`19988`: Removal of x-shared polar axes causes crash
* :ghissue:`20040`: AttributeError: module 'sip' has no attribute 'setapi'
* :ghissue:`20058`: bar_label fails with nan data values
* :ghissue:`20036`: Minor changes about stackplot documentation
* :ghissue:`20014`: undefined symbol: PyPyUnicode_ReadChar
* :ghissue:`19947`: Figure.subfigures dont show/update correctly
* :ghissue:`19960`: Failed to init RangeSlider with valinit attribute
* :ghissue:`19736`: subplot_mosaic axes are not added in consistent order
* :ghissue:`19979`: Blank EPS figures if plot contains 'd'
* :ghissue:`19938`: useless deprecation warning figbox
* :ghissue:`19958`: subfigures missing bbox_inches attribute in inline backend
* :ghissue:`19936`: Errorbars elinewidth raise error when numpy array
* :ghissue:`19879`: Using "drawstyle" raises AttributeError in errorbar, when yerr is specified.
* :ghissue:`19454`: I cannot import matplotlib.pyplot as plt
